@@ -1,3 +1,7 @@
+#' @rdname ComparisonTable
+#' @export cattable
+#' 
+
 cattable <- function(data, vars, byVar, fisher=NULL, fisher.arg=NULL,
                      cmh=NULL, row.score=NULL, col.score=NULL,
                      mcnemar=NULL, correct=NULL,
@@ -31,15 +35,21 @@ cattable <- function(data, vars, byVar, fisher=NULL, fisher.arg=NULL,
     miss.vars.msg <- paste("The following variables contain only missing values:", paste(miss.vars, collapse=", "))
     stop(miss.vars.msg)
   }
+  
+  if ("tbl_df" %in% class(data)) data <- as.data.frame(data)
 
   var.info <- function(v){
-    if (!is.factor(data[, v])) data[, v] <- factor(data[,v])
+    if (!is.factor(data[, v])){
+      v.lab <- Hmisc::label(data[, v])
+      data[, v] <- factor(data[,v])
+      Hmisc::label(data[, v]) <- v.lab
+    }
     
     nlev <- nlevels(data[, byVar])
     nlev.v <- nlevels(data[, v])
     
     .name <- c(v, rep(NA, nlev.v))
-    .label <- c(if (label(data[,v]) %in% "") v else label(data[, v]), rep(NA, nlev.v))
+    .label <- c(if (Hmisc::label(data[,v]) %in% "") v else Hmisc::label(data[, v]), rep(NA, nlev.v))
     .level <- c(NA, levels(data[, v]))
     .total <- c(sum(table(data[, v])), table(data[, v]))
     .count <- rbind(NA, table(data[, v], data[, byVar]))
@@ -64,16 +74,16 @@ cattable <- function(data, vars, byVar, fisher=NULL, fisher.arg=NULL,
     .odds.scale <- .odds.unit <- rep(NA, nlev.v + 1)
     if (v %in% odds){
       if (nlev == 2 & nlev.v > 1 & !0 %in% rowSums(.count)){
-        warn <- withWarnings(glm(data[, byVar] ~ data[, v], family=binomial))
+        warn <- withWarnings(stats::glm(data[, byVar] ~ data[, v], family=stats::binomial))
         if (!is.null(warn$warnings)) warning(v, "(glm): ", warn$warnings)
         m <- warn$value
         m$method <- "Logistic Regression"
-        warn <- withWarnings(confint(m, level=1 - alpha))
+        warn <- withWarnings(stats::confint(m, level=1 - alpha))
         if (!is.null(warn$warnings)) warning(paste(v, "(confint): ", 
                                                 unique(unlist(warn$warnings)), 
                                                 collapse="\n"))
         ci <- warn$value
-        .odds <- c(NA, 1.0, exp(coef(m)[-1]))
+        .odds <- c(NA, 1.0, exp(stats::coef(m)[-1]))
         .odds.lower <- c(NA, NA, exp(ci[-1,1]))
         .odds.upper <- c(NA, NA, exp(ci[-1,2]))
       }
@@ -133,7 +143,7 @@ cattable <- function(data, vars, byVar, fisher=NULL, fisher.arg=NULL,
       }
       else if(v %in% mcnemar){
         if (v %in% correct) cont <- TRUE else cont <- FALSE  
-        test.obj <- mcnemar.test(data[, v], data[, byVar], correct=cont)
+        test.obj <- stats::mcnemar.test(data[, v], data[, byVar], correct=cont)
         .test.method <- c(test.obj$method, rep(NA, nlev.v))
         .test.mark <- c("M", rep(NA, nlev.v))
         .test.stat <- ifelse(is.null(test.obj$estimate), NA, test.obj$estimate)
@@ -145,8 +155,8 @@ cattable <- function(data, vars, byVar, fisher=NULL, fisher.arg=NULL,
           test.obj <- m
           .test.method <- c(NA, NA, rep(test.obj$method, nlev.v - 1))
           .test.mark <- c(NA, NA, rep("L", nlev.v - 1))
-          .test.stat <- c(NA, 1.0, exp(coef(test.obj)[-1]))
-          .pvalue <- c(NA, NA, coef(summary(test.obj))[-1, 4])
+          .test.stat <- c(NA, 1.0, exp(stats::coef(test.obj)[-1]))
+          .pvalue <- c(NA, NA, stats::coef(summary(test.obj))[-1, 4])
         }
         else{
           .test.method <- NA
@@ -156,7 +166,7 @@ cattable <- function(data, vars, byVar, fisher=NULL, fisher.arg=NULL,
         }
       }
       else{
-        warn <- withWarnings(chisq.test(data[, v], data[, byVar]))
+        warn <- withWarnings(stats::chisq.test(data[, v], data[, byVar]))
         if (!is.null(warn$warnings)) warning(v, ": ", warn$warnings)
         test.obj <- warn$value
         .test.method <- c(test.obj$method, rep(NA, nlev.v))
@@ -185,7 +195,7 @@ cattable <- function(data, vars, byVar, fisher=NULL, fisher.arg=NULL,
     .df <- cbind(.name, .label, .level, .total, .df, .missing, .missingp,
                  .odds, .odds.lower, .odds.upper, .odds.scale, .odds.unit,
                  .test.method, .test.mark, .test.stat, .pvalue,
-                 is.significant(.pvalue), .type,
+                 is_significant(.pvalue), .type,
                  stringsAsFactors=FALSE)
     names(.df) <- c("name", "label", "level", "total", names.df, "missing", "missing.perc",
                     "odds", "odds.lower", "odds.upper",
@@ -211,8 +221,9 @@ cattable <- function(data, vars, byVar, fisher=NULL, fisher.arg=NULL,
   #data[, toFactor] <- lapply(data[, toFactor, drop=FALSE], factor)
   
   ctable <- do.call("rbind", lapply(vars, var.info))
+  ctable$type <- factor(ctable$type)
   attributes(ctable)$byVar <- data[, byVar]
-  label(attributes(ctable)$byVar) <- label(data[, byVar])
+  Hmisc::label(attributes(ctable)$byVar) <- Hmisc::label(data[, byVar])
   attributes(ctable)$vars <- vars  
   class(ctable) <- c("ctable", "data.frame")
   return(ctable)
